@@ -11,7 +11,7 @@ use Plack::Util::Accessor qw/
     force
 /;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub prepare_app {
     my ($self) = @_;
@@ -68,7 +68,7 @@ sub _add_link {
     for my $lib_path (@{$self->lib}) {
         next if $lib_path eq '.';
         $lib_path =~ s!/!\\!g if $^O eq 'MSWin32';
-        ${$body_ref} =~ s!(\Q$lib_path\E[/\\]+([^\.]+\.[^\s]+)\s+line\s+(\d+))!_link_html($1, $2, $3)!eg;
+        ${$body_ref} =~ s!(\Q$lib_path\E[/\\]+([^\.]+\.[^\s]+)\s+line\s+(\d+))[^<]!_link_html($1, $2, $3)!eg;
     }
 }
 
@@ -140,7 +140,7 @@ see more configurations on L<Plack::Middleware::StackTrace>
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource.png?_t=1456041087"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-StackTrace-LinkedSource/badge.png?_t=1456041087&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource.png?_t=1456124185"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-StackTrace-LinkedSource/badge.png?_t=1456124185&branch=master"/></a>
 
 =end html
 
